@@ -25,12 +25,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.12/Python-2.7.12' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.13/Python-2.7.13' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd6:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.12/Python-2.7.12/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.12/Python-2.7.12/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.13/Python-2.7.13/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.13/Python-2.7.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
@@ -46,8 +46,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
  'ENSUREPIP': 'no',
@@ -139,7 +139,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FTRUNCATE': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
- 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -231,7 +231,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
- 'HAVE_RAND_EGD': 0,
  'HAVE_READLINK': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RL_CALLBACK': 1,
@@ -357,16 +356,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'hppa-unknown-openbsd6.0',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.1',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/obj/ports/Python-2.7.12/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.12/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.12/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.12/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.12/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.13/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.13/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.13/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.13/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.13/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -388,7 +387,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBRARY_OBJS': '\\',
  'LIBS': '-lpthread  -lutil',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
- 'LINKCC': 'c++ -pthread',
+ 'LINKCC': 'cc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
@@ -402,7 +401,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MACHDESTLIB': '/usr/local/lib/python2.7',
  'MACH_C_THREADS': 0,
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'c++ -pthread',
+ 'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
@@ -467,7 +466,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.12/Python-2.7.12',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.13/Python-2.7.13',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -482,7 +481,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -505,13 +504,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SVNVERSION': 'echo Unversioned directory',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TANH_PRESERVES_ZERO_SIGN': 1,
+ 'TANH_PRESERVES_ZERO_SIGN': 0,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.12/Python-2.7.12 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.13/Python-2.7.13 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -534,14 +533,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-2.7.12/Python-2.7.12',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.12/Python-2.7.12',
- 'build': 'hppa-unknown-openbsd6.0',
- 'cross_compiling': 'no',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.13/Python-2.7.13',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.13/Python-2.7.13',
+ 'build': 'i386-unknown-openbsd6.1',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'hppa-unknown-openbsd6.0',
+ 'host': 'i386-unknown-openbsd6.1',
  'prefix': '/usr/local',
  'srcdir': '.'}
